


// --------------------------------------------------------------------------
//
// Note: These functions all came from the original Starsiege files as
// indicated in each section's heading.  However each function has one line
// added to it to permit the Admin to administer the server while still
// permitting him to also play the game.
//
//
// See the file RocksServerAdmin.cs for a detailed description of what this
// package does, and how to control it.
//
// --------------------------------------------------------------------------




// --------------------------------------------------------------------------
// --------------------------------------------------------------------------
// -------------------- came from CTFstdLib.cs ------------------------------
// --------------------------------------------------------------------------
// --------------------------------------------------------------------------

function player::onAdd(%this)
{
//	say(%this,0, *IDMULT_CTF_WELCOME);	      

	RocksPlayerOnAdd(%this);
}   

function vehicle::onAdd(%this)
{
	%team = getTeam(playerManager::vehicleIdToPlayerNum(%this));
	%color = teamToColor(%team);
	%flagKey = strcat(%color, "FlagCount");
	
   	adjTeamCount(%team, 1);
	
	//if the flag isn't at the base, but no one has it, correct situation
	if(dataRetrieve(0, %flagKey) && !dataRetrieve(0, strcat(%color, "FlagCarried")))
	{
		setFlag(%team, true);
	}

	RocksVehicleOnAdd(%this);
}

function vehicle::onDestroyed(%destroyed, %destroyer)
{
   %team = getTeam(%destroyed);
   adjTeamCount(%team, -1);
   %teamCount = getTeamPlayerCount(%team);      

   if(%teamCount < 1)
   {
	   setFlag(%team, false);					
   }

   %color = dataRetrieve(%destroyed, "hasFlag");
   %flagTeam = colorToTeam(%color);
   
   // if the destroyed vehicle has a flag, it goes back to it's base
   if (%color != "")
   {
      playerDropsFlag(%destroyed);
      
      // let everyone know this guy drops the flag
      %str =
         *IDMULT_CHAT_SURRENDER_FLAG_1 @
         getName( %destroyed )         @
         *IDMULT_CHAT_SURRENDER_FLAG_2 @ 
         %flagTeam                     @
         *IDMULT_CHAT_SURRENDER_FLAG_3;
      
      %soundFile = "";   
      if(%flagTeam == *IDSTR_TEAM_RED)
      {
         %soundFile = "red_flag_sur.wav";
      }
      else if(%flagTeam == *IDSTR_TEAM_BLUE)
      {
         %soundFile = "blue_flag_sur.wav";
      }
      else if(%flagTeam == *IDSTR_TEAM_YELLOW)
      {
         %soundFile = "yel_flag_sur.wav";
      }
      else
      {
         %soundFile = "purp_flag_sur.wav";
      }   
      
      say( 0, 0, %str, %soundFile );

            
      if($scoringFreeze == false)
      {     
         // destroyer's team gets credit for killing the carrier
         %destroyerTeam = getTeam(%destroyer);  
      
         // only give points if destroyed recovered his/her own flag
         if(%destroyerTeam == colorToTeam(%color))
         {
            %key = strcat(teamToColor(getTeam(%destroyer)), "CarriersKilled");
            dataStore(0, %key, 1 + dataRetrieve(0, %key));
            
            // player gets credit, too
            %player = playerManager::vehicleIdToPlayerNum(%destroyer);
            if(%player != 0)
            {
               %player.carriersKilled = %player.carriersKilled + 1;
            }
         }

         // echo the surrender to the console for logging
         echo(*IDSTR_CONSOLE_CTF_SURRENDER @ " " @ playerManager::vehicleIdToPlayerNum(%destroyed));                        
      }	  
   }
   else
   {
      // not a flag carrier ... is it an enemy?
      if($scoringFreeze == false)
      {
         if(getTeam(%destroyed) != getTeam(%destroyer))
         {
            %player = playerManager::vehicleIdToPlayerNum(%destroyer);
            if(%player != 0)
            {
               %player.genericKills = %player.genericKills + 1;
            }
         }
      }
   }
   
   // enforce the rules
   if(
      (getTeam(%destroyed) == getTeam(%destroyer)) &&
      (%destroyed != %destroyer)
   )
   {
      antiTeamKill(%destroyer);
   }

   vehicle::onDestroyedLog(%destroyed, %destroyer);
   
   // give the death messages...
   %message = getFancyDeathMessage(getHUDName(%destroyed), getHUDName(%destroyer));
   if(%message != "")
   {
      say( 0, 0, %message);
   }
	RocksVehicleOnDestroyed(%destroyed, %destroyer);
}

function vehicle::onScan(%scanned, %scanner)
{
	RocksVehicleOnScan(%scanned, %scanner);
}



// --------------------------------------------------------------------------
// --------------------------------------------------------------------------
// -------------------- came from multiplayerStdLib.cs ----------------------
// --------------------------------------------------------------------------
// --------------------------------------------------------------------------

function player::onRemove(%this)
{
   %vehicle = playerManager::playerNumToVehicleId(%this);
   if(%vehicle != 0)
   {
      if(%vehicle.pad != "")
      {
         // reset the special for the pad this guy was on
         %vehicle.pad.special = "";
      }
   }
	RocksPlayerOnRemove(%this);
}

function vehicle::onAttacked(%this, %attacker)
{
   if( $enableTeamHittingPenalty == True )
   {
      if($server::TeamPlay == true)
      {
         if( %this != %attacker )
         {
            if(getTeam(%this) == getTeam(%attacker))
            {
               if(dataRetrieve(%attacker, "onProbation") != True)
               {
                  dataStore(%attacker, "onProbation", True);
                  schedule("dataStore(" @ %attacker @ ", \"onProbation\", False);", $probeFrequency);         
                  dataStore(%attacker, "totalOffenses", (dataRetrieve(%attacker, "totalOffenses") + $teamHitPenalty));
                  
                  if( dataRetrieve(%attacker, "hasCountdownSpawned") != True)
                  {
                     countdownOffenses(%attacker);
                     dataStore(%attacker, "hasCountdownSpawned", True);
                  }

                  if( dataRetrieve(%attacker, "totalOffenses") >= $allowableOffenses )
                  {
                     violate(%attacker);
                     %player = playerManager::vehicleIdToPlayerNum(%attacker);
                     if(%player != 0)
                     {
                        say(%player, 1234, *IDMULT_SPANKED, "rules_violated.wav");
                     }
                  }
               }   
            }
         }
      }
   }
	RocksVehicleOnAttacked(%this, %attacker);
}


function vehicle::OnArrived(%vehicle, %where)
{
	RocksVehicleOnArrived(%vehicle, %where);
}



// --------------------------------------------------------------------------
// --------------------------------------------------------------------------
// -------------------- came from missionStdLib.cs --------------------------
// --------------------------------------------------------------------------
// --------------------------------------------------------------------------

function vehicle::onTargeted(%targeted, %targeter)
{
	RocksVehicleOnTargeted(%targeted, %targeter);
}

function structure::onScan(%scanned, %scanner)
{
	RocksStructureOnScan(%scanned, %scanner);
}

function onMissionPreLoad()
{
	RocksOnMissionPreLoad();
}

function onMissionEnd()
{
	logStandardMissionEnd();
	RocksOnMissionEnd();
}

